# TCRUtils

Useful stuff for tcr projects.

## Todo
- [x] if in timestr.to_int() there are both and only 1 each of: x.y.z and a\:b:c syntaxes then `days -= 1`
- [x] `to_str2` which shows in format `1d + 23:45:57`
- [x] update gp_scum.py to use tcrutils from pypi
- [x] `timestr.to_int()` should support weekdays
- [x] Add all docstrings
- [x] Fix floats not recognized and negative numbers not recognized
- [x] Also weekdays now need `days -= 1` (`((number_of_date_syntaxes) ^ (number_of_weekday_syntaxes) == 1) and`)
- [x] Add docstring to dict_zip and others
- [x] make docstrings use \<h1> // ###
- [x] Add optional syntax highlighting to print_iterable
  - [x] *Rewrite print_iterable, maybeeee?*
- [x] dir2()
- [X] add IFYs to discord.string
- [ ] ~~add Components[] constructor (returns both view and view.build())~~
- [x] tcr.insist()
- [x] Move the printer decorator into decorators file
- [x] Add doc to fmt_iterable when done
- [x] Fix when trailing_commas=False breaks 1-element tuples
- [x] Test ifys

~~<style>s{color: crimson;} b,strong{text-decoration:underline}</style>~~
<!-- I am MEGUMIN the greatest mage among crimson demons and wielder of EXPLOSION MAGIC -->
~~<style>p, li{font-family: "Hubot Sans Bold"; font-size: 17px}</style>~~
~~<style>code, pre{font-family: Consolas}</style>~~
~~<style>code{background-color: #271a45; border-radius: 4px; padding: 2px; padding-left: 5px; padding-right: 5px;}</style>~~
